# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/saas/v1/lock_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/saas/v1/lock_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/marketplace/licensemanager/saas/v1/lock_service.proto\x12/yandex.cloud.marketplace.licensemanager.saas.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"L\n\x11\x45nsureLockRequest\x12\x1c\n\x0einstance_token\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x45nsureLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"\'\n\x0eGetLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xa6\x03\n\x0bLockService\x12\xdd\x01\n\x06\x45nsure\x12\x42.yandex.cloud.marketplace.licensemanager.saas.v1.EnsureLockRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*,\n\x12\x45nsureLockMetadata\x12\x16licensemanager.v1.Lock\x82\xd3\xe4\x93\x02\x36\"1/marketplace/license-manager/saas/v1/locks/ensure:\x01*\x12\xb6\x01\n\x03Get\x12?.yandex.cloud.marketplace.licensemanager.saas.v1.GetLockRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/marketplace/license-manager/saas/v1/locks/{lock_id}B\x99\x01\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanager'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_token']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_token']._serialized_options = b'\350\3071\001'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._loaded_options = None
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._serialized_options = b'\350\3071\001'
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._serialized_options = b'\262\322*,\n\022EnsureLockMetadata\022\026licensemanager.v1.Lock\202\323\344\223\0026\"1/marketplace/license-manager/saas/v1/locks/ensure:\001*'
  _globals['_LOCKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/marketplace/license-manager/saas/v1/locks/{lock_id}'
  _globals['_ENSURELOCKREQUEST']._serialized_start=309
  _globals['_ENSURELOCKREQUEST']._serialized_end=385
  _globals['_ENSURELOCKMETADATA']._serialized_start=387
  _globals['_ENSURELOCKMETADATA']._serialized_end=424
  _globals['_GETLOCKREQUEST']._serialized_start=426
  _globals['_GETLOCKREQUEST']._serialized_end=465
  _globals['_LOCKSERVICE']._serialized_start=468
  _globals['_LOCKSERVICE']._serialized_end=890
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ydb.v1.backup_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListPathsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """Required. ID of the YDB backup."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListPaths requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListPaths
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPathsRequest = ListPathsRequest

@typing.final
class ListPathsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "paths", b"paths"]) -> None: ...

global___ListPathsResponse = ListPathsResponse

@typing.final
class GetBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """Required. ID of the YDB backup."""
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id"]) -> None: ...

global___GetBackupRequest = GetBackupRequest

@typing.final
class ListBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListBackups requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListBackups
    request to get the next page of results.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListBackupsRequest = ListBackupsRequest

@typing.final
class ListBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListBackups requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListBackups request. Subsequent ListBackups
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def backups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ydb.v1.backup_pb2.Backup]: ...
    def __init__(
        self,
        *,
        backups: collections.abc.Iterable[yandex.cloud.ydb.v1.backup_pb2.Backup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backups", b"backups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListBackupsResponse = ListBackupsResponse

@typing.final
class DeleteBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id"]) -> None: ...

global___DeleteBackupRequest = DeleteBackupRequest

@typing.final
class DeleteBackupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    DATABASE_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    database_id: builtins.str
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        database_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "database_id", b"database_id"]) -> None: ...

global___DeleteBackupMetadata = DeleteBackupMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.greenplum.v1.config_pb2
import yandex.cloud.mdb.greenplum.v1.maintenance_pb2
import yandex.cloud.mdb.greenplum.v1.pxf_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """A Greenplum® cluster resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy: only hotfixes are applied during regular maintenance."""
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions are rolled out irrespective of backward compatibility."""

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy: only hotfixes are applied during regular maintenance."""
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions are rolled out irrespective of backward compatibility."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """Health of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is working normally ([Host.health] for every host in the cluster is ALIVE)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""
        UNBALANCED: Cluster._Health.ValueType  # 4
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is UNBALANCED)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """Health of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is working normally ([Host.health] for every host in the cluster is ALIVE)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""
    UNBALANCED: Cluster.Health.ValueType  # 4
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is UNBALANCED)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster has encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster has stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Current state of the cluster."""

    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster has encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster has stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    MASTER_CONFIG_FIELD_NUMBER: builtins.int
    SEGMENT_CONFIG_FIELD_NUMBER: builtins.int
    MASTER_HOST_COUNT_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_COUNT_FIELD_NUMBER: builtins.int
    SEGMENT_IN_HOST_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_FIELD_NUMBER: builtins.int
    MASTER_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Greenplum® cluster.
    This ID is assigned by the platform at the moment of cluster creation.
    """
    folder_id: builtins.str
    """ID of the folder that the Greenplum® cluster belongs to."""
    name: builtins.str
    """Name of the Greenplum® cluster.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the Greenplum® cluster."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the Greenplum® cluster."""
    master_host_count: builtins.int
    """Number of hosts in the master subcluster."""
    segment_host_count: builtins.int
    """Number of hosts in the segment subcluster."""
    segment_in_host: builtins.int
    """Number of segments per host."""
    network_id: builtins.str
    """ID of the cloud network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    user_name: builtins.str
    """Owner user name."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    service_account_id: builtins.str
    """Service account that will be used to access a Yandex Cloud resources"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the cluster was created."""

    @property
    def config(self) -> global___GreenplumConfig:
        """Greenplum® cluster configuration."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Greenplum® cluster as `key:value` pairs. Maximum 64 labels per resource."""

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the Greenplum® cluster."""

    @property
    def master_config(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.MasterSubclusterConfig:
        """Configuration of the Greenplum® master subcluster."""

    @property
    def segment_config(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.SegmentSubclusterConfig:
        """Configuration of the Greenplum® segment subcluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow:
        """A Greenplum® cluster maintenance window. Should be defined by either one of the two options."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceOperation:
        """Maintenance operation planned at nearest [maintenance_window]."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the cluster."""

    @property
    def cluster_config(self) -> global___ClusterConfigSet:
        """Greenplum® and Odyssey® configuration."""

    @property
    def cloud_storage(self) -> global___CloudStorage:
        """Cloud storage settings"""

    @property
    def master_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the master subcluster."""

    @property
    def segment_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the segment subcluster."""

    @property
    def logging(self) -> global___LoggingConfig:
        """Cloud logging configuration"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        config: global___GreenplumConfig | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        master_config: yandex.cloud.mdb.greenplum.v1.config_pb2.MasterSubclusterConfig | None = ...,
        segment_config: yandex.cloud.mdb.greenplum.v1.config_pb2.SegmentSubclusterConfig | None = ...,
        master_host_count: builtins.int = ...,
        segment_host_count: builtins.int = ...,
        segment_in_host: builtins.int = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        maintenance_window: yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        user_name: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        cluster_config: global___ClusterConfigSet | None = ...,
        cloud_storage: global___CloudStorage | None = ...,
        master_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        segment_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        logging: global___LoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "cluster_config", b"cluster_config", "config", b"config", "created_at", b"created_at", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "planned_operation", b"planned_operation", "segment_config", b"segment_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "cluster_config", b"cluster_config", "config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "host_group_ids", b"host_group_ids", "id", b"id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "master_host_count", b"master_host_count", "master_host_group_ids", b"master_host_group_ids", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "segment_config", b"segment_config", "segment_host_count", b"segment_host_count", "segment_host_group_ids", b"segment_host_group_ids", "segment_in_host", b"segment_in_host", "service_account_id", b"service_account_id", "status", b"status", "user_name", b"user_name"]) -> None: ...

global___Cluster = Cluster

@typing.final
class ClusterConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GREENPLUM_CONFIG_SET_6_17_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_SET_6_19_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_SET_6_21_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_SET_6_22_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_SET_6_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    BACKGROUND_ACTIVITIES_FIELD_NUMBER: builtins.int
    PXF_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def greenplum_config_set_6_17(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_17: ...
    @property
    def greenplum_config_set_6_19(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_19: ...
    @property
    def greenplum_config_set_6_21(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_21: ...
    @property
    def greenplum_config_set_6_22(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_22: ...
    @property
    def greenplum_config_set_6(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6: ...
    @property
    def pool(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.ConnectionPoolerConfigSet:
        """Odyssey® pool settings."""

    @property
    def background_activities(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.BackgroundActivitiesConfig:
        """Managed Greenplum® background tasks configuration."""

    @property
    def pxf_config(self) -> yandex.cloud.mdb.greenplum.v1.pxf_pb2.PXFConfigSet: ...
    def __init__(
        self,
        *,
        greenplum_config_set_6_17: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_17 | None = ...,
        greenplum_config_set_6_19: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_19 | None = ...,
        greenplum_config_set_6_21: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_21 | None = ...,
        greenplum_config_set_6_22: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6_22 | None = ...,
        greenplum_config_set_6: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfigSet6 | None = ...,
        pool: yandex.cloud.mdb.greenplum.v1.config_pb2.ConnectionPoolerConfigSet | None = ...,
        background_activities: yandex.cloud.mdb.greenplum.v1.config_pb2.BackgroundActivitiesConfig | None = ...,
        pxf_config: yandex.cloud.mdb.greenplum.v1.pxf_pb2.PXFConfigSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["background_activities", b"background_activities", "greenplum_config", b"greenplum_config", "greenplum_config_set_6", b"greenplum_config_set_6", "greenplum_config_set_6_17", b"greenplum_config_set_6_17", "greenplum_config_set_6_19", b"greenplum_config_set_6_19", "greenplum_config_set_6_21", b"greenplum_config_set_6_21", "greenplum_config_set_6_22", b"greenplum_config_set_6_22", "pool", b"pool", "pxf_config", b"pxf_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["background_activities", b"background_activities", "greenplum_config", b"greenplum_config", "greenplum_config_set_6", b"greenplum_config_set_6", "greenplum_config_set_6_17", b"greenplum_config_set_6_17", "greenplum_config_set_6_19", b"greenplum_config_set_6_19", "greenplum_config_set_6_21", b"greenplum_config_set_6_21", "greenplum_config_set_6_22", b"greenplum_config_set_6_22", "pool", b"pool", "pxf_config", b"pxf_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["greenplum_config", b"greenplum_config"]) -> typing.Literal["greenplum_config_set_6_17", "greenplum_config_set_6_19", "greenplum_config_set_6_21", "greenplum_config_set_6_22", "greenplum_config_set_6"] | None: ...

global___ClusterConfigSet = ClusterConfigSet

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the Greenplum® cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class GreenplumConfig(google.protobuf.message.Message):
    """Greenplum® cluster configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of the Greenplum® server software."""
    zone_id: builtins.str
    """ID of the availability zone the cluster belongs to.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    subnet_id: builtins.str
    """ID of the subnet the cluster belongs to. This subnet should be a part of the cloud network the cluster belongs to (see [Cluster.network_id])."""
    assign_public_ip: builtins.bool
    """Determines whether the cluster has a public IP address.

    After the cluster has been created, this setting cannot be changed.
    """
    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def backup_retain_period_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Retention policy of automated backups."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        backup_retain_period_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        access: global___Access | None = ...,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "assign_public_ip", b"assign_public_ip", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "subnet_id", b"subnet_id", "version", b"version", "zone_id", b"zone_id"]) -> None: ...

global___GreenplumConfig = GreenplumConfig

@typing.final
class Access(google.protobuf.message.Message):
    """Greenplum® cluster access options."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    YANDEX_QUERY_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allows data export from the cluster to DataLens."""
    web_sql: builtins.bool
    """Allows SQL queries to the cluster databases from the management console."""
    data_transfer: builtins.bool
    """Allows access for DataTransfer."""
    yandex_query: builtins.bool
    """Allow access for YandexQuery."""
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
        data_transfer: builtins.bool = ...,
        yandex_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "data_transfer", b"data_transfer", "web_sql", b"web_sql", "yandex_query", b"yandex_query"]) -> None: ...

global___Access = Access

@typing.final
class GreenplumRestoreConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the host resides.

    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request.
    """
    subnet_id: builtins.str
    """ID of the subnet that the host should belong to. This subnet should be a part of the network that the cluster belongs to.
    The ID of the network is set in the field [Cluster.network_id].
    """
    assign_public_ip: builtins.bool
    """Determines whether the host should get a public IP address on creation.

    After a host has been created, this setting cannot be changed.

    To remove an assigned public IP, or to assign a public IP to a host without one, recreate the host with [assign_public_ip] set as needed.

    Possible values:
    * `false` - do not assign a public IP to the master host.
    * `true` - assign a public IP to the master host.
    """
    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def access(self) -> global___Access:
        """Access policy for external services."""

    def __init__(
        self,
        *,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        access: global___Access | None = ...,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        assign_public_ip: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "backup_window_start", b"backup_window_start"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "assign_public_ip", b"assign_public_ip", "backup_window_start", b"backup_window_start", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___GreenplumRestoreConfig = GreenplumRestoreConfig

@typing.final
class RestoreResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory, etc.)."""
    disk_size: builtins.int
    """Volume of the storage available to a host."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___RestoreResources = RestoreResources

@typing.final
class CloudStorage(google.protobuf.message.Message):
    """Cloud Storage Settings"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    """enable Cloud Storage for cluster"""
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enable", b"enable"]) -> None: ...

global___CloudStorage = CloudStorage

@typing.final
class LoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    COMMAND_CENTER_ENABLED_FIELD_NUMBER: builtins.int
    GREENPLUM_ENABLED_FIELD_NUMBER: builtins.int
    POOLER_ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    folder_id: builtins.str
    log_group_id: builtins.str
    command_center_enabled: builtins.bool
    """send Yandex Command Center logs"""
    greenplum_enabled: builtins.bool
    """send Greenplum logs"""
    pooler_enabled: builtins.bool
    """send Pooler logs"""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        folder_id: builtins.str = ...,
        log_group_id: builtins.str = ...,
        command_center_enabled: builtins.bool = ...,
        greenplum_enabled: builtins.bool = ...,
        pooler_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["command_center_enabled", b"command_center_enabled", "destination", b"destination", "enabled", b"enabled", "folder_id", b"folder_id", "greenplum_enabled", b"greenplum_enabled", "log_group_id", b"log_group_id", "pooler_enabled", b"pooler_enabled"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["folder_id", "log_group_id"] | None: ...

global___LoggingConfig = LoggingConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/subnet.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/subnet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/vpc/v1/subnet.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8d\x03\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x37\n\x06labels\x18\x06 \x03(\x0b\x32\'.yandex.cloud.vpc.v1.Subnet.LabelsEntry\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x0f\n\x07zone_id\x18\x08 \x01(\t\x12\x16\n\x0ev4_cidr_blocks\x18\n \x03(\t\x12\x16\n\x0ev6_cidr_blocks\x18\x0b \x03(\t\x12\x16\n\x0eroute_table_id\x18\x0c \x01(\t\x12\x36\n\x0c\x64hcp_options\x18\r \x01(\x0b\x32 .yandex.cloud.vpc.v1.DhcpOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\t\x10\n\"T\n\x0b\x44hcpOptions\x12\x1b\n\x13\x64omain_name_servers\x18\x01 \x03(\t\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\x13\n\x0bntp_servers\x18\x03 \x03(\t*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42V\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.subnet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _globals['_SUBNET_LABELSENTRY']._loaded_options = None
  _globals['_SUBNET_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_IPVERSION']._serialized_start=576
  _globals['_IPVERSION']._serialized_end=635
  _globals['_SUBNET']._serialized_start=91
  _globals['_SUBNET']._serialized_end=488
  _globals['_SUBNET_LABELSENTRY']._serialized_start=437
  _globals['_SUBNET_LABELSENTRY']._serialized_end=482
  _globals['_DHCPOPTIONS']._serialized_start=490
  _globals['_DHCPOPTIONS']._serialized_end=574
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/lifecycle_policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/lifecycle_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/containerregistry/v1/lifecycle_policy.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x02\n\x0fLifecyclePolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12I\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.Status\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x05rules\x18\x07 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\":\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xbc\x01\n\rLifecycleRule\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\rexpire_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05>=24h\x12\x1d\n\ntag_regexp\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08untagged\x18\x04 \x01(\x08\x12\x1d\n\x0cretained_top\x18\x05 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.lifecycle_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_LIFECYCLERULE'].fields_by_name['description']._loaded_options = None
  _globals['_LIFECYCLERULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_LIFECYCLERULE'].fields_by_name['expire_period']._loaded_options = None
  _globals['_LIFECYCLERULE'].fields_by_name['expire_period']._serialized_options = b'\372\3071\005>=24h'
  _globals['_LIFECYCLERULE'].fields_by_name['tag_regexp']._loaded_options = None
  _globals['_LIFECYCLERULE'].fields_by_name['tag_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_LIFECYCLERULE'].fields_by_name['retained_top']._loaded_options = None
  _globals['_LIFECYCLERULE'].fields_by_name['retained_top']._serialized_options = b'\372\3071\003>=0'
  _globals['_LIFECYCLEPOLICY']._serialized_start=192
  _globals['_LIFECYCLEPOLICY']._serialized_end=527
  _globals['_LIFECYCLEPOLICY_STATUS']._serialized_start=469
  _globals['_LIFECYCLEPOLICY_STATUS']._serialized_end=527
  _globals['_LIFECYCLERULE']._serialized_start=530
  _globals['_LIFECYCLERULE']._serialized_end=718
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.group_mapping_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class GroupMappingServiceStub:
    """RPC service dedicated for federation group mapping."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingRequest,
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingResponse,
    ]
    """Returns a group mapping configured for the specific federation
    If a federation does not exist this call will return an error
       NOT_FOUND will be returned
    If a federation exist, but has not ever been configured for group mapping
      the call FAILED_PRECONDITION will be returned.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.CreateGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a group mapping for a federation
    If mapping already exist, ALREADY_EXISTS will be returned
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing group mapping for a federation
    Errors:
    - if federation is not found
    In case of any error, no changes are applied to existing group mapping

    This call is idempotent. The following actions do nothing:
    - enabling when already enabled
    - disabling when disabled
    Such parts of request will be ignored. Others will be applied.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.DeleteGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a group mapping. This will remove all the mapping items
    cascade.
    """

    ListItems: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsRequest,
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsResponse,
    ]
    """Returns all the group mappings items

    Filtering is only supported by external_group_id or internal_group_id
    """

    UpdateItems: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingItemsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates group mapping items for a specified federation
    Errors:
    - if federation is not found
    - if internal group in the mapping added does not exist
    In case of any error, no changes are applied to existing group mapping

    This call is idempotent. The following actions do nothing:
    - adding group mapping items that are already present
    - removing group mapping items that are not present
    Such parts of request will be ignored. Others will be applied.
    """

class GroupMappingServiceAsyncStub:
    """RPC service dedicated for federation group mapping."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingRequest,
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingResponse,
    ]
    """Returns a group mapping configured for the specific federation
    If a federation does not exist this call will return an error
       NOT_FOUND will be returned
    If a federation exist, but has not ever been configured for group mapping
      the call FAILED_PRECONDITION will be returned.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.CreateGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a group mapping for a federation
    If mapping already exist, ALREADY_EXISTS will be returned
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing group mapping for a federation
    Errors:
    - if federation is not found
    In case of any error, no changes are applied to existing group mapping

    This call is idempotent. The following actions do nothing:
    - enabling when already enabled
    - disabling when disabled
    Such parts of request will be ignored. Others will be applied.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.DeleteGroupMappingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a group mapping. This will remove all the mapping items
    cascade.
    """

    ListItems: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsRequest,
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsResponse,
    ]
    """Returns all the group mappings items

    Filtering is only supported by external_group_id or internal_group_id
    """

    UpdateItems: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingItemsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates group mapping items for a specified federation
    Errors:
    - if federation is not found
    - if internal group in the mapping added does not exist
    In case of any error, no changes are applied to existing group mapping

    This call is idempotent. The following actions do nothing:
    - adding group mapping items that are already present
    - removing group mapping items that are not present
    Such parts of request will be ignored. Others will be applied.
    """

class GroupMappingServiceServicer(metaclass=abc.ABCMeta):
    """RPC service dedicated for federation group mapping."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.GetGroupMappingResponse]]:
        """Returns a group mapping configured for the specific federation
        If a federation does not exist this call will return an error
           NOT_FOUND will be returned
        If a federation exist, but has not ever been configured for group mapping
          the call FAILED_PRECONDITION will be returned.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.CreateGroupMappingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a group mapping for a federation
        If mapping already exist, ALREADY_EXISTS will be returned
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an existing group mapping for a federation
        Errors:
        - if federation is not found
        In case of any error, no changes are applied to existing group mapping

        This call is idempotent. The following actions do nothing:
        - enabling when already enabled
        - disabling when disabled
        Such parts of request will be ignored. Others will be applied.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.DeleteGroupMappingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a group mapping. This will remove all the mapping items
        cascade.
        """

    @abc.abstractmethod
    def ListItems(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.ListGroupMappingItemsResponse]]:
        """Returns all the group mappings items

        Filtering is only supported by external_group_id or internal_group_id
        """

    @abc.abstractmethod
    def UpdateItems(
        self,
        request: yandex.cloud.organizationmanager.v1.group_mapping_service_pb2.UpdateGroupMappingItemsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates group mapping items for a specified federation
        Errors:
        - if federation is not found
        - if internal group in the mapping added does not exist
        In case of any error, no changes are applied to existing group mapping

        This call is idempotent. The following actions do nothing:
        - adding group mapping items that are already present
        - removing group mapping items that are not present
        Such parts of request will be ignored. Others will be applied.
        """

def add_GroupMappingServiceServicer_to_server(servicer: GroupMappingServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/security_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/security_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/vpc/v1/security_group.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xeb\x03\n\rSecurityGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.vpc.v1.SecurityGroup.LabelsEntry\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x39\n\x06status\x18\x08 \x01(\x0e\x32).yandex.cloud.vpc.v1.SecurityGroup.Status\x12\x35\n\x05rules\x18\t \x03(\x0b\x32&.yandex.cloud.vpc.v1.SecurityGroupRule\x12\x1b\n\x13\x64\x65\x66\x61ult_for_network\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"\x94\x04\n\x11SecurityGroupRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x06labels\x18\x03 \x03(\x0b\x32\x32.yandex.cloud.vpc.v1.SecurityGroupRule.LabelsEntry\x12I\n\tdirection\x18\x04 \x01(\x0e\x32\x30.yandex.cloud.vpc.v1.SecurityGroupRule.DirectionB\x04\xe8\xc7\x31\x01\x12-\n\x05ports\x18\x05 \x01(\x0b\x32\x1e.yandex.cloud.vpc.v1.PortRange\x12\x15\n\rprotocol_name\x18\x06 \x01(\t\x12\x17\n\x0fprotocol_number\x18\x07 \x01(\x03\x12\x36\n\x0b\x63idr_blocks\x18\x08 \x01(\x0b\x32\x1f.yandex.cloud.vpc.v1.CidrBlocksH\x00\x12\x1b\n\x11security_group_id\x18\t \x01(\tH\x00\x12\x1b\n\x11predefined_target\x18\n \x01(\tH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\tDirection\x12\x19\n\x15\x44IRECTION_UNSPECIFIED\x10\x00\x12\x0b\n\x07INGRESS\x10\x01\x12\n\n\x06\x45GRESS\x10\x02\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"I\n\tPortRange\x12\x1e\n\tfrom_port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x1c\n\x07to_port\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\"<\n\nCidrBlocks\x12\x16\n\x0ev4_cidr_blocks\x18\x01 \x03(\t\x12\x16\n\x0ev6_cidr_blocks\x18\x02 \x03(\tBV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.security_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _globals['_SECURITYGROUP_LABELSENTRY']._loaded_options = None
  _globals['_SECURITYGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYGROUPRULE_LABELSENTRY']._loaded_options = None
  _globals['_SECURITYGROUPRULE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYGROUPRULE'].oneofs_by_name['target']._loaded_options = None
  _globals['_SECURITYGROUPRULE'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_SECURITYGROUPRULE'].fields_by_name['direction']._loaded_options = None
  _globals['_SECURITYGROUPRULE'].fields_by_name['direction']._serialized_options = b'\350\3071\001'
  _globals['_PORTRANGE'].fields_by_name['from_port']._loaded_options = None
  _globals['_PORTRANGE'].fields_by_name['from_port']._serialized_options = b'\372\3071\0070-65535'
  _globals['_PORTRANGE'].fields_by_name['to_port']._loaded_options = None
  _globals['_PORTRANGE'].fields_by_name['to_port']._serialized_options = b'\372\3071\0070-65535'
  _globals['_SECURITYGROUP']._serialized_start=130
  _globals['_SECURITYGROUP']._serialized_end=621
  _globals['_SECURITYGROUP_LABELSENTRY']._serialized_start=488
  _globals['_SECURITYGROUP_LABELSENTRY']._serialized_end=533
  _globals['_SECURITYGROUP_STATUS']._serialized_start=535
  _globals['_SECURITYGROUP_STATUS']._serialized_end=621
  _globals['_SECURITYGROUPRULE']._serialized_start=624
  _globals['_SECURITYGROUPRULE']._serialized_end=1156
  _globals['_SECURITYGROUPRULE_LABELSENTRY']._serialized_start=488
  _globals['_SECURITYGROUPRULE_LABELSENTRY']._serialized_end=533
  _globals['_SECURITYGROUPRULE_DIRECTION']._serialized_start=1077
  _globals['_SECURITYGROUPRULE_DIRECTION']._serialized_end=1140
  _globals['_PORTRANGE']._serialized_start=1158
  _globals['_PORTRANGE']._serialized_end=1231
  _globals['_CIDRBLOCKS']._serialized_start=1233
  _globals['_CIDRBLOCKS']._serialized_end=1293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/assistant_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/assistant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1 import assistant_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_assistant__pb2
from yandex.cloud.ai.assistants.v1 import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_common__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/ai/assistants/v1/assistant_service.proto\x12\x1dyandex.cloud.ai.assistants.v1\x1a#yandex/cloud/ai/common/common.proto\x1a-yandex/cloud/ai/assistants/v1/assistant.proto\x1a*yandex/cloud/ai/assistants/v1/common.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\xa6\x04\n\x16\x43reateAssistantRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x04 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12Q\n\x06labels\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.ai.assistants.v1.CreateAssistantRequest.LabelsEntry\x12\x17\n\tmodel_uri\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0binstruction\x18\x07 \x01(\t\x12Y\n\x19prompt_truncation_options\x18\x08 \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.PromptTruncationOptions\x12L\n\x12\x63ompletion_options\x18\t \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.CompletionOptions\x12\x32\n\x05tools\x18\n \x03(\x0b\x32#.yandex.cloud.ai.assistants.v1.Tool\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x13GetAssistantRequest\x12\x1a\n\x0c\x61ssistant_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xda\x04\n\x16UpdateAssistantRequest\x12\x1a\n\x0c\x61ssistant_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12Q\n\x06labels\x18\x06 \x03(\x0b\x32\x41.yandex.cloud.ai.assistants.v1.UpdateAssistantRequest.LabelsEntry\x12\x11\n\tmodel_uri\x18\x07 \x01(\t\x12\x13\n\x0binstruction\x18\x08 \x01(\t\x12Y\n\x19prompt_truncation_options\x18\t \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.PromptTruncationOptions\x12L\n\x12\x63ompletion_options\x18\n \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.CompletionOptions\x12\x32\n\x05tools\x18\x0b \x03(\x0b\x32#.yandex.cloud.ai.assistants.v1.Tool\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x16\x44\x65leteAssistantRequest\x12\x1a\n\x0c\x61ssistant_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x19\n\x17\x44\x65leteAssistantResponse\"W\n\x15ListAssistantsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x16ListAssistantsResponse\x12<\n\nassistants\x18\x01 \x03(\x0b\x32(.yandex.cloud.ai.assistants.v1.Assistant\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\x1cListAssistantVersionsRequest\x12\x1a\n\x0c\x61ssistant_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8c\x01\n\x10\x41ssistantVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12;\n\tassistant\x18\x03 \x01(\x0b\x32(.yandex.cloud.ai.assistants.v1.Assistant\"{\n\x1dListAssistantVersionsResponse\x12\x41\n\x08versions\x18\x01 \x03(\x0b\x32/.yandex.cloud.ai.assistants.v1.AssistantVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xde\x07\n\x10\x41ssistantService\x12\x8f\x01\n\x06\x43reate\x12\x35.yandex.cloud.ai.assistants.v1.CreateAssistantRequest\x1a(.yandex.cloud.ai.assistants.v1.Assistant\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/assistants/v1/assistants:\x01*\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.ai.assistants.v1.GetAssistantRequest\x1a(.yandex.cloud.ai.assistants.v1.Assistant\"0\x82\xd3\xe4\x93\x02*\x12(/assistants/v1/assistants/{assistant_id}\x12\x9e\x01\n\x06Update\x12\x35.yandex.cloud.ai.assistants.v1.UpdateAssistantRequest\x1a(.yandex.cloud.ai.assistants.v1.Assistant\"3\x82\xd3\xe4\x93\x02-2(/assistants/v1/assistants/{assistant_id}:\x01*\x12\xa9\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.ai.assistants.v1.DeleteAssistantRequest\x1a\x36.yandex.cloud.ai.assistants.v1.DeleteAssistantResponse\"0\x82\xd3\xe4\x93\x02**(/assistants/v1/assistants/{assistant_id}\x12\x96\x01\n\x04List\x12\x34.yandex.cloud.ai.assistants.v1.ListAssistantsRequest\x1a\x35.yandex.cloud.ai.assistants.v1.ListAssistantsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/assistants/v1/assistants\x12\xb9\x01\n\x0cListVersions\x12;.yandex.cloud.ai.assistants.v1.ListAssistantVersionsRequest\x1a<.yandex.cloud.ai.assistants.v1.ListAssistantVersionsResponse\".\x82\xd3\xe4\x93\x02(\x12&/assistants/v1/assistants:listVersionsBq\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.assistant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistants'
  _globals['_CREATEASSISTANTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEASSISTANTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEASSISTANTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEASSISTANTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEASSISTANTREQUEST'].fields_by_name['model_uri']._loaded_options = None
  _globals['_CREATEASSISTANTREQUEST'].fields_by_name['model_uri']._serialized_options = b'\350\3071\001'
  _globals['_GETASSISTANTREQUEST'].fields_by_name['assistant_id']._loaded_options = None
  _globals['_GETASSISTANTREQUEST'].fields_by_name['assistant_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEASSISTANTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEASSISTANTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEASSISTANTREQUEST'].fields_by_name['assistant_id']._loaded_options = None
  _globals['_UPDATEASSISTANTREQUEST'].fields_by_name['assistant_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEASSISTANTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEASSISTANTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_DELETEASSISTANTREQUEST'].fields_by_name['assistant_id']._loaded_options = None
  _globals['_DELETEASSISTANTREQUEST'].fields_by_name['assistant_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTASSISTANTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTASSISTANTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTASSISTANTVERSIONSREQUEST'].fields_by_name['assistant_id']._loaded_options = None
  _globals['_LISTASSISTANTVERSIONSREQUEST'].fields_by_name['assistant_id']._serialized_options = b'\350\3071\001'
  _globals['_ASSISTANTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\036\"\031/assistants/v1/assistants:\001*'
  _globals['_ASSISTANTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/assistants/v1/assistants/{assistant_id}'
  _globals['_ASSISTANTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['Update']._serialized_options = b'\202\323\344\223\002-2(/assistants/v1/assistants/{assistant_id}:\001*'
  _globals['_ASSISTANTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002**(/assistants/v1/assistants/{assistant_id}'
  _globals['_ASSISTANTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/assistants/v1/assistants'
  _globals['_ASSISTANTSERVICE'].methods_by_name['ListVersions']._loaded_options = None
  _globals['_ASSISTANTSERVICE'].methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002(\022&/assistants/v1/assistants:listVersions'
  _globals['_CREATEASSISTANTREQUEST']._serialized_start=312
  _globals['_CREATEASSISTANTREQUEST']._serialized_end=862
  _globals['_CREATEASSISTANTREQUEST_LABELSENTRY']._serialized_start=817
  _globals['_CREATEASSISTANTREQUEST_LABELSENTRY']._serialized_end=862
  _globals['_GETASSISTANTREQUEST']._serialized_start=864
  _globals['_GETASSISTANTREQUEST']._serialized_end=913
  _globals['_UPDATEASSISTANTREQUEST']._serialized_start=916
  _globals['_UPDATEASSISTANTREQUEST']._serialized_end=1518
  _globals['_UPDATEASSISTANTREQUEST_LABELSENTRY']._serialized_start=817
  _globals['_UPDATEASSISTANTREQUEST_LABELSENTRY']._serialized_end=862
  _globals['_DELETEASSISTANTREQUEST']._serialized_start=1520
  _globals['_DELETEASSISTANTREQUEST']._serialized_end=1572
  _globals['_DELETEASSISTANTRESPONSE']._serialized_start=1574
  _globals['_DELETEASSISTANTRESPONSE']._serialized_end=1599
  _globals['_LISTASSISTANTSREQUEST']._serialized_start=1601
  _globals['_LISTASSISTANTSREQUEST']._serialized_end=1688
  _globals['_LISTASSISTANTSRESPONSE']._serialized_start=1690
  _globals['_LISTASSISTANTSRESPONSE']._serialized_end=1801
  _globals['_LISTASSISTANTVERSIONSREQUEST']._serialized_start=1803
  _globals['_LISTASSISTANTVERSIONSREQUEST']._serialized_end=1900
  _globals['_ASSISTANTVERSION']._serialized_start=1903
  _globals['_ASSISTANTVERSION']._serialized_end=2043
  _globals['_LISTASSISTANTVERSIONSRESPONSE']._serialized_start=2045
  _globals['_LISTASSISTANTVERSIONSRESPONSE']._serialized_end=2168
  _globals['_ASSISTANTSERVICE']._serialized_start=2171
  _globals['_ASSISTANTSERVICE']._serialized_end=3161
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/snapshot_schedule_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/snapshot_schedule_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import snapshot_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__pb2
from yandex.cloud.compute.v1 import snapshot_schedule_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_snapshot__schedule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/compute/v1/snapshot_schedule_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/compute/v1/snapshot.proto\x1a/yandex/cloud/compute/v1/snapshot_schedule.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x1aGetSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"\xb6\x01\n\x1cListSnapshotSchedulesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x7f\n\x1dListSnapshotSchedulesResponse\x12\x45\n\x12snapshot_schedules\x18\x01 \x03(\x0b\x32).yandex.cloud.compute.v1.SnapshotSchedule\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xcf\x03\n\x1d\x43reateSnapshotScheduleRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12R\n\x06labels\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.CreateSnapshotScheduleRequest.LabelsEntry\x12@\n\x0fschedule_policy\x18\x05 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\x07 \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x12\x10\n\x08\x64isk_ids\x18\t \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10retention_policy\">\n\x1e\x43reateSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"\xf9\x03\n\x1dUpdateSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12R\n\x06labels\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest.LabelsEntry\x12@\n\x0fschedule_policy\x18\x06 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\x08 \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\t \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10retention_policy\">\n\x1eUpdateSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"=\n\x1d\x44\x65leteSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x44\x65leteSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x44isableSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"?\n\x1f\x44isableSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"=\n\x1d\x45nableSnapshotScheduleRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\">\n\x1e\x45nableSnapshotScheduleMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\"l\n%ListSnapshotScheduleOperationsRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"x\n&ListSnapshotScheduleOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"k\n$ListSnapshotScheduleSnapshotsRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n%ListSnapshotScheduleSnapshotsResponse\x12\x34\n\tsnapshots\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n ListSnapshotScheduleDisksRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"j\n!ListSnapshotScheduleDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"_\n\"UpdateSnapshotScheduleDisksRequest\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t\x12\x0e\n\x06remove\x18\x02 \x03(\t\x12\x0b\n\x03\x61\x64\x64\x18\x03 \x03(\t\"C\n#UpdateSnapshotScheduleDisksMetadata\x12\x1c\n\x14snapshot_schedule_id\x18\x01 \x01(\t2\xee\x17\n\x17SnapshotScheduleService\x12\xa3\x01\n\x03Get\x12\x33.yandex.cloud.compute.v1.GetSnapshotScheduleRequest\x1a).yandex.cloud.compute.v1.SnapshotSchedule\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/compute/v1/snapshotSchedules/{snapshot_schedule_id}\x12\x9c\x01\n\x04List\x12\x35.yandex.cloud.compute.v1.ListSnapshotSchedulesRequest\x1a\x36.yandex.cloud.compute.v1.ListSnapshotSchedulesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/compute/v1/snapshotSchedules\x12\xc3\x01\n\x06\x43reate\x12\x36.yandex.cloud.compute.v1.CreateSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*2\n\x1e\x43reateSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x82\xd3\xe4\x93\x02\"\"\x1d/compute/v1/snapshotSchedules:\x01*\x12\xda\x01\n\x06Update\x12\x36.yandex.cloud.compute.v1.UpdateSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*2\n\x1eUpdateSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x82\xd3\xe4\x93\x02\x39\x32\x34/compute/v1/snapshotSchedules/{snapshot_schedule_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12\x36.yandex.cloud.compute.v1.DeleteSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*7\n\x1e\x44\x65leteSnapshotScheduleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/compute/v1/snapshotSchedules/{snapshot_schedule_id}\x12\xf6\x01\n\x0bUpdateDisks\x12;.yandex.cloud.compute.v1.UpdateSnapshotScheduleDisksRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*7\n#UpdateSnapshotScheduleDisksMetadata\x12\x10SnapshotSchedule\x82\xd3\xe4\x93\x02\x45\x32@/compute/v1/snapshotSchedules/{snapshot_schedule_id}:updateDisks:\x01*\x12\xe5\x01\n\x07\x44isable\x12\x37.yandex.cloud.compute.v1.DisableSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*3\n\x1f\x44isableSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x82\xd3\xe4\x93\x02\x41\"</compute/v1/snapshotSchedules/{snapshot_schedule_id}:disable:\x01*\x12\xe1\x01\n\x06\x45nable\x12\x36.yandex.cloud.compute.v1.EnableSnapshotScheduleRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*2\n\x1e\x45nableSnapshotScheduleMetadata\x12\x10SnapshotSchedule\x82\xd3\xe4\x93\x02@\";/compute/v1/snapshotSchedules/{snapshot_schedule_id}:enable:\x01*\x12\xda\x01\n\x0eListOperations\x12>.yandex.cloud.compute.v1.ListSnapshotScheduleOperationsRequest\x1a?.yandex.cloud.compute.v1.ListSnapshotScheduleOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/compute/v1/snapshotSchedules/{snapshot_schedule_id}/operations\x12\xd6\x01\n\rListSnapshots\x12=.yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsRequest\x1a>.yandex.cloud.compute.v1.ListSnapshotScheduleSnapshotsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/compute/v1/snapshotSchedules/{snapshot_schedule_id}/snapshots\x12\xc6\x01\n\tListDisks\x12\x39.yandex.cloud.compute.v1.ListSnapshotScheduleDisksRequest\x1a:.yandex.cloud.compute.v1.ListSnapshotScheduleDisksResponse\"B\x82\xd3\xe4\x93\x02<\x12:/compute/v1/snapshotSchedules/{snapshot_schedule_id}/disks\x12\xbd\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/compute/v1/snapshotSchedules/{resource_id}:listAccessBindings\x12\xfc\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x42\"=/compute/v1/snapshotSchedules/{resource_id}:setAccessBindings:\x01*\x12\x88\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9a\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x45\"@/compute/v1/snapshotSchedules/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.snapshot_schedule_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/compute/v1/snapshotSchedules/{snapshot_schedule_id}'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/compute/v1/snapshotSchedules'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*2\n\036CreateSnapshotScheduleMetadata\022\020SnapshotSchedule\202\323\344\223\002\"\"\035/compute/v1/snapshotSchedules:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*2\n\036UpdateSnapshotScheduleMetadata\022\020SnapshotSchedule\202\323\344\223\002924/compute/v1/snapshotSchedules/{snapshot_schedule_id}:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*7\n\036DeleteSnapshotScheduleMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/compute/v1/snapshotSchedules/{snapshot_schedule_id}'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['UpdateDisks']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['UpdateDisks']._serialized_options = b'\262\322*7\n#UpdateSnapshotScheduleDisksMetadata\022\020SnapshotSchedule\202\323\344\223\002E2@/compute/v1/snapshotSchedules/{snapshot_schedule_id}:updateDisks:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Disable']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Disable']._serialized_options = b'\262\322*3\n\037DisableSnapshotScheduleMetadata\022\020SnapshotSchedule\202\323\344\223\002A\"</compute/v1/snapshotSchedules/{snapshot_schedule_id}:disable:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Enable']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['Enable']._serialized_options = b'\262\322*2\n\036EnableSnapshotScheduleMetadata\022\020SnapshotSchedule\202\323\344\223\002@\";/compute/v1/snapshotSchedules/{snapshot_schedule_id}:enable:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/compute/v1/snapshotSchedules/{snapshot_schedule_id}/operations'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListSnapshots']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListSnapshots']._serialized_options = b'\202\323\344\223\002@\022>/compute/v1/snapshotSchedules/{snapshot_schedule_id}/snapshots'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListDisks']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListDisks']._serialized_options = b'\202\323\344\223\002<\022:/compute/v1/snapshotSchedules/{snapshot_schedule_id}/disks'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002@\022>/compute/v1/snapshotSchedules/{resource_id}:listAccessBindings'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002B\"=/compute/v1/snapshotSchedules/{resource_id}:setAccessBindings:\001*'
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_SNAPSHOTSCHEDULESERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002E\"@/compute/v1/snapshotSchedules/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETSNAPSHOTSCHEDULEREQUEST']._serialized_start=444
  _globals['_GETSNAPSHOTSCHEDULEREQUEST']._serialized_end=502
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST']._serialized_start=505
  _globals['_LISTSNAPSHOTSCHEDULESREQUEST']._serialized_end=687
  _globals['_LISTSNAPSHOTSCHEDULESRESPONSE']._serialized_start=689
  _globals['_LISTSNAPSHOTSCHEDULESRESPONSE']._serialized_end=816
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST']._serialized_start=819
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST']._serialized_end=1282
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_start=1217
  _globals['_CREATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_end=1262
  _globals['_CREATESNAPSHOTSCHEDULEMETADATA']._serialized_start=1284
  _globals['_CREATESNAPSHOTSCHEDULEMETADATA']._serialized_end=1346
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST']._serialized_start=1349
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST']._serialized_end=1854
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_start=1217
  _globals['_UPDATESNAPSHOTSCHEDULEREQUEST_LABELSENTRY']._serialized_end=1262
  _globals['_UPDATESNAPSHOTSCHEDULEMETADATA']._serialized_start=1856
  _globals['_UPDATESNAPSHOTSCHEDULEMETADATA']._serialized_end=1918
  _globals['_DELETESNAPSHOTSCHEDULEREQUEST']._serialized_start=1920
  _globals['_DELETESNAPSHOTSCHEDULEREQUEST']._serialized_end=1981
  _globals['_DELETESNAPSHOTSCHEDULEMETADATA']._serialized_start=1983
  _globals['_DELETESNAPSHOTSCHEDULEMETADATA']._serialized_end=2045
  _globals['_DISABLESNAPSHOTSCHEDULEREQUEST']._serialized_start=2047
  _globals['_DISABLESNAPSHOTSCHEDULEREQUEST']._serialized_end=2109
  _globals['_DISABLESNAPSHOTSCHEDULEMETADATA']._serialized_start=2111
  _globals['_DISABLESNAPSHOTSCHEDULEMETADATA']._serialized_end=2174
  _globals['_ENABLESNAPSHOTSCHEDULEREQUEST']._serialized_start=2176
  _globals['_ENABLESNAPSHOTSCHEDULEREQUEST']._serialized_end=2237
  _globals['_ENABLESNAPSHOTSCHEDULEMETADATA']._serialized_start=2239
  _globals['_ENABLESNAPSHOTSCHEDULEMETADATA']._serialized_end=2301
  _globals['_LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST']._serialized_start=2303
  _globals['_LISTSNAPSHOTSCHEDULEOPERATIONSREQUEST']._serialized_end=2411
  _globals['_LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE']._serialized_start=2413
  _globals['_LISTSNAPSHOTSCHEDULEOPERATIONSRESPONSE']._serialized_end=2533
  _globals['_LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST']._serialized_start=2535
  _globals['_LISTSNAPSHOTSCHEDULESNAPSHOTSREQUEST']._serialized_end=2642
  _globals['_LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE']._serialized_start=2644
  _globals['_LISTSNAPSHOTSCHEDULESNAPSHOTSRESPONSE']._serialized_end=2762
  _globals['_LISTSNAPSHOTSCHEDULEDISKSREQUEST']._serialized_start=2764
  _globals['_LISTSNAPSHOTSCHEDULEDISKSREQUEST']._serialized_end=2867
  _globals['_LISTSNAPSHOTSCHEDULEDISKSRESPONSE']._serialized_start=2869
  _globals['_LISTSNAPSHOTSCHEDULEDISKSRESPONSE']._serialized_end=2975
  _globals['_UPDATESNAPSHOTSCHEDULEDISKSREQUEST']._serialized_start=2977
  _globals['_UPDATESNAPSHOTSCHEDULEDISKSREQUEST']._serialized_end=3072
  _globals['_UPDATESNAPSHOTSCHEDULEDISKSMETADATA']._serialized_start=3074
  _globals['_UPDATESNAPSHOTSCHEDULEDISKSMETADATA']._serialized_end=3141
  _globals['_SNAPSHOTSCHEDULESERVICE']._serialized_start=3144
  _globals['_SNAPSHOTSCHEDULESERVICE']._serialized_end=6198
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CronTab(google.protobuf.message.Message):
    """Message to describe a crontab schedule."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_MONTH_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    day_of_month: builtins.str
    month: builtins.str
    day_of_week: builtins.str
    def __init__(
        self,
        *,
        day_of_month: builtins.str = ...,
        month: builtins.str = ...,
        day_of_week: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day_of_month", b"day_of_month", "day_of_week", b"day_of_week", "month", b"month"]) -> None: ...

global___CronTab = CronTab

@typing.final
class BackupRetentionPolicy(google.protobuf.message.Message):
    """Message to describe a retention policy for cluster backups."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CRON_FIELD_NUMBER: builtins.int
    RETAIN_FOR_DAYS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Required. Policy ID."""
    cluster_id: builtins.str
    """PostgreSQL cluster ID."""
    policy_name: builtins.str
    """Required. Policy name."""
    retain_for_days: builtins.int
    """Retention duration."""
    description: builtins.str
    """Human-readable description."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def cron(self) -> global___CronTab:
        """CronTab schedule."""

    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        policy_name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cron: global___CronTab | None = ...,
        retain_for_days: builtins.int = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "cron", b"cron"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "created_at", b"created_at", "cron", b"cron", "description", b"description", "policy_id", b"policy_id", "policy_name", b"policy_name", "retain_for_days", b"retain_for_days"]) -> None: ...

global___BackupRetentionPolicy = BackupRetentionPolicy
